Crate poem_http_common

Crate poem_http_common 

Modules

dev_proxy
Poem-proxy is a simple and easy-to-use proxy Endpoint compatible with the Poem Web Framework. It supports the forwarding of http get and post requests as well as websockets right out of the box!
embed_file
middleware
response