ProxyConfig

Struct ProxyConfig 

pub struct ProxyConfig { /* private fields */ }
A configuration object that allows for fine-grained control over a proxy endpoint.

Implementations

Source

impl ProxyConfig

Implementation of Builder Functions

The ProxyConfig struct follows the builder pattern to enable explicit and succinct configuration of the proxy endpoint.

pub fn new<'a>(target: impl Into<String>) -> ProxyConfig

Function that creates a new ProxyConfig for a given target and sets all other parameters to their default values. See the default implementation for more information.

pub fn web_secure<'a>(&'a mut self) -> &'a mut ProxyConfig

This function sets the endpoint to forward requests to the target over the https protocol. This is a secure and encrypted communication channel that should be utilized when possible.

pub fn web_insecure<'a>(&'a mut self) -> &'a mut ProxyConfig

This function sets the endpoint to forward requests to the target over the http protocol. This is an insecure and unencrypted communication channel that should be used very carefully.

pub fn enable_nesting<'a>(&'a mut self) -> &'a mut ProxyConfig

This function sets the waypoint to support nesting.

For example, if endpoint.target is https://google.com and the proxy is reached at https://proxy_address/favicon.png, the proxy server will forward the request to https://google.com/favicon.png.

pub fn disable_nesting<'a>(&'a mut self) -> &'a mut ProxyConfig

This function sets the waypoint to ignore nesting.

For example, if endpoint.target is https://google.com and the proxy is reached at https://proxy_address/favicon.png, the proxy server will forward the request to https://google.com.

pub fn finish<'a>(&'a mut self) -> ProxyConfig

Finishes off the building process by returning a new ProxyConfig object (not reference) that contains all the settings that were previously specified.

Source

impl ProxyConfig

Convenience Functions

These functions make it possible to get information from the ProxyConfig struct.

pub fn get_web_request_uri(&self, subpath: Option<String>) -> Result<String, ()>

Returns the target url of the request, including the proper protocol information and the correct pathing if nesting is enabled

An example output would be

"https://proxy.domain.com"